\name{PeriodicPenalty}
\alias{PeriodicPenalty}
\title{A Roughness Penalty Based on Periodicity}
\description{
A penalty against violation of periodicity.
}
\usage{
PeriodicPenalty(xgrid, a, period, x.range)
}
\arguments{
\item{xgrid}{vector of length m, must be increasing}
\item{a}{a function of one numeric variable}
\item{period}{a numeric constant, must be positive-valued}
\item{x.range}{a numeric vector of length 2, range of predictor variable}
}
\value{
a vector of differences, a(x+period) - a(x), evaluated at the points of xgrid
}
\author{W.J. Braun}
\examples{
n <- 50
sigma <- 0.1
xx <- seq(0, 1, length = n)
g <- function(x) cos(6*pi*x)
yy <- g(xx) + rnorm(n, sd = sigma)
d <- 1 # local polynomial degree
yy.ll <- locpoly(xx, yy, bandwidth = .0158, degree = d) # good local linear fit
xgrid <- seq(0, 1, length = 401)
period <- 1/3
yy.lp <- penlocreg(xx, yy, xgrid, degree = d, h = .008, lambda = 10,
          L = PeriodicPenalty, period = period, x.range = c(0,1)) # sharpened data
yy.lpr <- locpoly(yy.lp$x, yy.lp$y, degree=1, bandwidth = .008) 
mean((g(yy.lpr$x) - yy.lpr$y)^2)/mean((g(yy.ll$x) - yy.ll$y)^2) # accuracy comparison
plot(xx, yy)
lines(locpoly(xx, yy, bandwidth = .0158, degree = 1)) # local linear curve is black
    yy.lp <- penlocreg(xx, yy, xgrid, degree = d, h = .008, lambda = 10,
          L = PeriodicPenalty, period = period, x.range=c(0,1)) 
lines(locpoly(yy.lp$x, yy.lp$y, degree = 1, bandwidth = .008), col = 2) # penalized curve is red
curve(g(x), add = TRUE, col = 3) # true curve is green
}

\keyword{models}
