\name{penlocreg}
\alias{penlocreg}
\title{Penalized Local Polynomial Regression}
\description{
Data sharpened local polynomial regression subject to a given penalty.
}
\usage{
penlocreg(x, y, xgrid, degree = 0, h, lambda, L, ...)
}
\arguments{
\item{x}{numeric vector of predictor observations}
\item{y}{numeric vector of observed responses}
\item{xgrid}{numeric vector of grid points where regression function is evaluated}
\item{degree}{numeric vector of local polynomial regression degree}
\item{h}{numeric bandwidth}
\item{lambda}{numeric penalty constant}
\item{L}{function related to penalty}
\item{...}{additional arguments, as required by L}
}
\value{
a list containing the original observed predictor values, the
sharpened responses, the smoother matrix and the penalty matrix
}
\author{W.J. Braun}
\examples{
n <- 50
sigma <- 0.1
xx <- seq(0, 1, length = n)
g <- function(x) cos(6*pi*x)
yy <- g(xx) + rnorm(n, sd = sigma)
d <- 1 # local polynomial degree
yy.ll <- locpoly(xx, yy, bandwidth = .0158, degree = d) # good local linear fit
xgrid <- seq(0, 1, length = 401)
period <- 1/3
yy.lp <- penlocreg(xx, yy, xgrid, degree = d, h = .008, lambda = 10,
          L = PeriodicPenalty, period = period, x.range = c(0,1)) # sharpened data
yy.lpr <- locpoly(yy.lp$x, yy.lp$y, degree=1, bandwidth = .008) 
mean((g(yy.lpr$x) - yy.lpr$y)^2)/mean((g(yy.ll$x) - yy.ll$y)^2) # accuracy comparison
plot(xx, yy)
lines(locpoly(xx, yy, bandwidth = .0158, degree = 1)) # local linear curve is black
    yy.lp <- penlocreg(xx, yy, xgrid, degree = d, h = .008, lambda = 10,
          L = PeriodicPenalty, period = period, x.range=c(0,1)) 
lines(locpoly(yy.lp$x, yy.lp$y, degree = 1, bandwidth = .008), col = 2) # penalized curve is red
curve(g(x), add = TRUE, col = 3) # true curve is green
}

\keyword{models}


